/*=========================================================================

  Program:   Insight Segmentation & Registration Toolkit
  Module:    itkFEMMaterials.h
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

  Copyright (c) Insight Software Consortium. All rights reserved.
  See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even 
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
     PURPOSE.  See the above copyright notices for more information.

=========================================================================*/
#ifndef __itkFEMMaterials_h
#define __itkFEMMaterials_h

/**
 * \file itkFEMMaterials.h
 * \brief Include all finite element material classes defined in FEM toolkit.
 *
 * To make sure you have included all Material classes,
 * just include this header file.
 */
#include "itkFEMMaterialBase.h"
#include "itkFEMMaterialLinearElasticity.h"
#endif
